All of lore.kernel.org
 help / color / mirror / Atom feed
* [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree
@ 2022-04-27  6:25 Andrew Morton
  2022-04-27  6:41 ` Miaohe Lin
  0 siblings, 1 reply; 4+ messages in thread
From: Andrew Morton @ 2022-04-27  6:25 UTC (permalink / raw)
  To: mm-commits, ying.huang, osalvador, iamjoonsoo.kim, hch, linmiaohe, akpm


The patch titled
     Subject: mm/vmscan: activate swap-backed executable folios after first usage
has been removed from the -mm tree.  Its filename was
     mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch

This patch was dropped because it was nacked

------------------------------------------------------
From: Miaohe Lin <linmiaohe@huawei.com>
Subject: mm/vmscan: activate swap-backed executable folios after first usage

We should activate swap-backed executable folios (e.g.  tmpfs) after first
usage so that executable code gets yet better chance to stay in memory.

Link: https://lkml.kernel.org/r/20220425111232.23182-4-linmiaohe@huawei.com
Signed-off-by: Miaohe Lin <linmiaohe@huawei.com>
Suggested-by: Huang, Ying <ying.huang@intel.com>
Reviewed-by: Huang, Ying <ying.huang@intel.com>
Cc: Joonsoo Kim <iamjoonsoo.kim@lge.com>
Cc: Christoph Hellwig <hch@lst.de>
Cc: Oscar Salvador <osalvador@suse.de>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---

 mm/vmscan.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

--- a/mm/vmscan.c~mm-vmscan-activate-swap-backed-executable-folios-after-first-usage
+++ a/mm/vmscan.c
@@ -1412,9 +1412,9 @@ static enum page_references folio_check_
 			return PAGEREF_ACTIVATE;
 
 		/*
-		 * Activate file-backed executable folios after first usage.
+		 * Activate executable folios after first usage.
 		 */
-		if ((vm_flags & VM_EXEC) && !folio_test_swapbacked(folio))
+		if (vm_flags & VM_EXEC)
 			return PAGEREF_ACTIVATE;
 
 		return PAGEREF_KEEP;
_

Patches currently in -mm which might be from linmiaohe@huawei.com are

mm-shmem-make-shmem_init-return-void.patch
mm-memcg-remove-unneeded-nr_scanned.patch
mm-memory-failurec-minor-cleanup-for-hwpoisonhandlable.patch
mm-memory-failurec-dissolve-truncated-hugetlb-page.patch
mm-vmscan-remove-obsolete-comment-in-get_scan_count.patch
mm-vmscan-fix-comment-for-current_may_throttle.patch
mm-vmscan-fix-comment-for-isolate_lru_pages.patch
mm-z3fold-declare-z3fold_mount-with-__init.patch
mm-z3fold-remove-obsolete-comment-in-z3fold_alloc.patch
mm-z3fold-minor-clean-up-for-z3fold_free.patch
mm-z3fold-remove-unneeded-page_mapcount_reset-and-clearpageprivate.patch
mm-z3fold-remove-confusing-local-variable-l-reassignment.patch
mm-z3fold-move-decrement-of-pool-pages_nr-into-__release_z3fold_page.patch
mm-z3fold-remove-redundant-list_del_init-of-zhdr-buddy-in-z3fold_free.patch
mm-z3fold-remove-unneeded-page_headless-check-in-free_handle.patch
mm-compaction-use-helper-isolation_suitable.patch
drivers-base-nodec-fix-compaction-sysfs-file-leak.patch
mm-mempolicy-clean-up-the-code-logic-in-queue_pages_pte_range.patch
mm-migration-remove-unneeded-local-variable-mapping_locked.patch
mm-migration-remove-unneeded-local-variable-page_lru.patch
mm-migration-use-helper-function-vma_lookup-in-add_page_for_migration.patch
mm-migration-use-helper-macro-min-in-do_pages_stat.patch
mm-migration-avoid-unneeded-nodemask_t-initialization.patch
mm-migration-remove-some-duplicated-codes-in-migrate_pages.patch
mm-migration-fix-potential-page-refcounts-leak-in-migrate_pages.patch
mm-migration-fix-potential-invalid-node-access-for-reclaim-based-migration.patch
mm-migration-fix-possible-do_pages_stat_array-racing-with-memory-offline.patch
mm-madvise-fix-potential-pte_unmap_unlock-pte-error.patch
mm-mmapc-use-helper-mlock_future_check.patch
mm-mremap-use-helper-mlock_future_check.patch
mm-mremap-avoid-unneeded-do_munmap-call.patch
mm-compaction-remove-unneeded-return-value-of-kcompactd_run.patch
mm-compaction-remove-unneeded-pfn-update.patch
mm-compaction-remove-unneeded-assignment-to-isolate_start_pfn.patch
mm-compaction-clean-up-comment-for-sched-contention.patch
mm-compaction-clean-up-comment-about-suitable-migration-target-recheck.patch
mm-compaction-use-compact_cluster_max-in-compactionc.patch
mm-compaction-use-helper-compound_nr-in-isolate_migratepages_block.patch
mm-compaction-clean-up-comment-about-async-compaction-in-isolate_migratepages.patch
mm-compaction-avoid-possible-null-pointer-dereference-in-kcompactd_cpu_online.patch
mm-compaction-make-compaction_zonelist_suitable-return-false-when-compact_success.patch
mm-compaction-simplify-the-code-in-__compact_finished.patch
mm-compaction-make-sure-highest-is-above-the-min_pfn.patch
mm-swapfile-unuse_pte-can-map-random-data-if-swap-read-fails.patch
mm-swapfile-fix-lost-swap-bits-in-unuse_pte.patch
mm-madvise-free-hwpoison-and-swapin-error-entry-in-madvise_free_pte_range.patch
mm-migration-reduce-the-rcu-lock-duration.patch
mm-migration-remove-unneeded-lock-page-and-pagemovable-check.patch
mm-migration-return-errno-when-isolate_huge_page-failed.patch
mm-migration-fix-potential-pte_unmap-on-an-not-mapped-pte.patch
mm-vmscan-take-min_slab_pages-into-account-when-try-to-call-shrink_node.patch
mm-vmscan-add-a-comment-about-madv_free-pages-check-in-folio_check_dirty_writeback.patch
mm-vmscan-introduce-helper-function-reclaim_page_list.patch
mm-vmscan-take-all-base-pages-of-thp-into-account-when-race-with-speculative-reference.patch
mm-vmscan-remove-obsolete-comment-in-kswapd_run.patch
mm-vmscan-use-helper-folio_is_file_lru.patch


^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree
  2022-04-27  6:25 [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree Andrew Morton
@ 2022-04-27  6:41 ` Miaohe Lin
  2022-04-27 14:16   ` Andrew Morton
  0 siblings, 1 reply; 4+ messages in thread
From: Miaohe Lin @ 2022-04-27  6:41 UTC (permalink / raw)
  To: Andrew Morton; +Cc: mm-commits, ying.huang, osalvador, iamjoonsoo.kim, hch

On 2022/4/27 14:25, Andrew Morton wrote:
> 
> The patch titled
>      Subject: mm/vmscan: activate swap-backed executable folios after first usage
> has been removed from the -mm tree.  Its filename was
>      mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch
> 
> This patch was dropped because it was nacked

Hi Andrew,

Since this patch is nacked, should I resend the whole series with this patch dropped?
And I'd like to change this patch to use the helper folio_is_file_lru too, something like below:

diff --git a/mm/vmscan.c b/mm/vmscan.c
index ed484a0e9cd0..60ccbebec4c8 100644
--- a/mm/vmscan.c
+++ b/mm/vmscan.c
@@ -1412,9 +1412,9 @@ static enum page_references folio_check_references(struct folio *folio,
                        return PAGEREF_ACTIVATE;

                /*
                 * Activate executable folios after first usage.
                 */
-               if (vm_flags & VM_EXEC)
+               if ((vm_flags & VM_EXEC) && folio_is_file_lru(folio))
                        return PAGEREF_ACTIVATE;

                return PAGEREF_KEEP;

Should I send this patch separately or resend the whole series with this new change attached?

Many thanks!

> 
> ------------------------------------------------------
> From: Miaohe Lin <linmiaohe@huawei.com>
> Subject: mm/vmscan: activate swap-backed executable folios after first usage
> 
> We should activate swap-backed executable folios (e.g.  tmpfs) after first
> usage so that executable code gets yet better chance to stay in memory.
> 
> Link: https://lkml.kernel.org/r/20220425111232.23182-4-linmiaohe@huawei.com
> Signed-off-by: Miaohe Lin <linmiaohe@huawei.com>
> Suggested-by: Huang, Ying <ying.huang@intel.com>
> Reviewed-by: Huang, Ying <ying.huang@intel.com>
> Cc: Joonsoo Kim <iamjoonsoo.kim@lge.com>
> Cc: Christoph Hellwig <hch@lst.de>
> Cc: Oscar Salvador <osalvador@suse.de>
> Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
> ---
> 
>  mm/vmscan.c |    4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)
> 
> --- a/mm/vmscan.c~mm-vmscan-activate-swap-backed-executable-folios-after-first-usage
> +++ a/mm/vmscan.c
> @@ -1412,9 +1412,9 @@ static enum page_references folio_check_
>  			return PAGEREF_ACTIVATE;
>  
>  		/*
> -		 * Activate file-backed executable folios after first usage.
> +		 * Activate executable folios after first usage.
>  		 */
> -		if ((vm_flags & VM_EXEC) && !folio_test_swapbacked(folio))
> +		if (vm_flags & VM_EXEC)
>  			return PAGEREF_ACTIVATE;
>  
>  		return PAGEREF_KEEP;
> _
> 
> Patches currently in -mm which might be from linmiaohe@huawei.com are
> 
> mm-shmem-make-shmem_init-return-void.patch
> mm-memcg-remove-unneeded-nr_scanned.patch
> mm-memory-failurec-minor-cleanup-for-hwpoisonhandlable.patch
> mm-memory-failurec-dissolve-truncated-hugetlb-page.patch
> mm-vmscan-remove-obsolete-comment-in-get_scan_count.patch
> mm-vmscan-fix-comment-for-current_may_throttle.patch
> mm-vmscan-fix-comment-for-isolate_lru_pages.patch
> mm-z3fold-declare-z3fold_mount-with-__init.patch
> mm-z3fold-remove-obsolete-comment-in-z3fold_alloc.patch
> mm-z3fold-minor-clean-up-for-z3fold_free.patch
> mm-z3fold-remove-unneeded-page_mapcount_reset-and-clearpageprivate.patch
> mm-z3fold-remove-confusing-local-variable-l-reassignment.patch
> mm-z3fold-move-decrement-of-pool-pages_nr-into-__release_z3fold_page.patch
> mm-z3fold-remove-redundant-list_del_init-of-zhdr-buddy-in-z3fold_free.patch
> mm-z3fold-remove-unneeded-page_headless-check-in-free_handle.patch
> mm-compaction-use-helper-isolation_suitable.patch
> drivers-base-nodec-fix-compaction-sysfs-file-leak.patch
> mm-mempolicy-clean-up-the-code-logic-in-queue_pages_pte_range.patch
> mm-migration-remove-unneeded-local-variable-mapping_locked.patch
> mm-migration-remove-unneeded-local-variable-page_lru.patch
> mm-migration-use-helper-function-vma_lookup-in-add_page_for_migration.patch
> mm-migration-use-helper-macro-min-in-do_pages_stat.patch
> mm-migration-avoid-unneeded-nodemask_t-initialization.patch
> mm-migration-remove-some-duplicated-codes-in-migrate_pages.patch
> mm-migration-fix-potential-page-refcounts-leak-in-migrate_pages.patch
> mm-migration-fix-potential-invalid-node-access-for-reclaim-based-migration.patch
> mm-migration-fix-possible-do_pages_stat_array-racing-with-memory-offline.patch
> mm-madvise-fix-potential-pte_unmap_unlock-pte-error.patch
> mm-mmapc-use-helper-mlock_future_check.patch
> mm-mremap-use-helper-mlock_future_check.patch
> mm-mremap-avoid-unneeded-do_munmap-call.patch
> mm-compaction-remove-unneeded-return-value-of-kcompactd_run.patch
> mm-compaction-remove-unneeded-pfn-update.patch
> mm-compaction-remove-unneeded-assignment-to-isolate_start_pfn.patch
> mm-compaction-clean-up-comment-for-sched-contention.patch
> mm-compaction-clean-up-comment-about-suitable-migration-target-recheck.patch
> mm-compaction-use-compact_cluster_max-in-compactionc.patch
> mm-compaction-use-helper-compound_nr-in-isolate_migratepages_block.patch
> mm-compaction-clean-up-comment-about-async-compaction-in-isolate_migratepages.patch
> mm-compaction-avoid-possible-null-pointer-dereference-in-kcompactd_cpu_online.patch
> mm-compaction-make-compaction_zonelist_suitable-return-false-when-compact_success.patch
> mm-compaction-simplify-the-code-in-__compact_finished.patch
> mm-compaction-make-sure-highest-is-above-the-min_pfn.patch
> mm-swapfile-unuse_pte-can-map-random-data-if-swap-read-fails.patch
> mm-swapfile-fix-lost-swap-bits-in-unuse_pte.patch
> mm-madvise-free-hwpoison-and-swapin-error-entry-in-madvise_free_pte_range.patch
> mm-migration-reduce-the-rcu-lock-duration.patch
> mm-migration-remove-unneeded-lock-page-and-pagemovable-check.patch
> mm-migration-return-errno-when-isolate_huge_page-failed.patch
> mm-migration-fix-potential-pte_unmap-on-an-not-mapped-pte.patch
> mm-vmscan-take-min_slab_pages-into-account-when-try-to-call-shrink_node.patch
> mm-vmscan-add-a-comment-about-madv_free-pages-check-in-folio_check_dirty_writeback.patch
> mm-vmscan-introduce-helper-function-reclaim_page_list.patch
> mm-vmscan-take-all-base-pages-of-thp-into-account-when-race-with-speculative-reference.patch
> mm-vmscan-remove-obsolete-comment-in-kswapd_run.patch
> mm-vmscan-use-helper-folio_is_file_lru.patch
> 
> .
> 


^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree
  2022-04-27  6:41 ` Miaohe Lin
@ 2022-04-27 14:16   ` Andrew Morton
  2022-04-28  1:59     ` Miaohe Lin
  0 siblings, 1 reply; 4+ messages in thread
From: Andrew Morton @ 2022-04-27 14:16 UTC (permalink / raw)
  To: Miaohe Lin; +Cc: mm-commits, ying.huang, osalvador, iamjoonsoo.kim, hch

On Wed, 27 Apr 2022 14:41:30 +0800 Miaohe Lin <linmiaohe@huawei.com> wrote:

> On 2022/4/27 14:25, Andrew Morton wrote:
> > 
> > The patch titled
> >      Subject: mm/vmscan: activate swap-backed executable folios after first usage
> > has been removed from the -mm tree.  Its filename was
> >      mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch
> > 
> > This patch was dropped because it was nacked
> 
> Hi Andrew,
> 
> Since this patch is nacked, should I resend the whole series with this patch dropped?
> And I'd like to change this patch to use the helper folio_is_file_lru too, something like below:
> 
> diff --git a/mm/vmscan.c b/mm/vmscan.c
> index ed484a0e9cd0..60ccbebec4c8 100644
> --- a/mm/vmscan.c
> +++ b/mm/vmscan.c
> @@ -1412,9 +1412,9 @@ static enum page_references folio_check_references(struct folio *folio,
>                         return PAGEREF_ACTIVATE;
> 
>                 /*
> -                * Activate executable folios after first usage.
> +                * Activate file-backed executable folios after first usage.
>                  */
> -               if (vm_flags & VM_EXEC)
> +               if ((vm_flags & VM_EXEC) && folio_is_file_lru(folio))
>                         return PAGEREF_ACTIVATE;
> 
>                 return PAGEREF_KEEP;
> 
> Should I send this patch separately or resend the whole series with this new change attached?
> 

I dropped this patch individually, so there's no need to resend the others.

^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree
  2022-04-27 14:16   ` Andrew Morton
@ 2022-04-28  1:59     ` Miaohe Lin
  0 siblings, 0 replies; 4+ messages in thread
From: Miaohe Lin @ 2022-04-28  1:59 UTC (permalink / raw)
  To: Andrew Morton; +Cc: mm-commits, ying.huang, osalvador, iamjoonsoo.kim, hch

On 2022/4/27 22:16, Andrew Morton wrote:
> On Wed, 27 Apr 2022 14:41:30 +0800 Miaohe Lin <linmiaohe@huawei.com> wrote:
> 
>> On 2022/4/27 14:25, Andrew Morton wrote:
>>>
>>> The patch titled
>>>      Subject: mm/vmscan: activate swap-backed executable folios after first usage
>>> has been removed from the -mm tree.  Its filename was
>>>      mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch
>>>
>>> This patch was dropped because it was nacked
>>
>> Hi Andrew,
>>
>> Since this patch is nacked, should I resend the whole series with this patch dropped?
>> And I'd like to change this patch to use the helper folio_is_file_lru too, something like below:
>>
>> diff --git a/mm/vmscan.c b/mm/vmscan.c
>> index ed484a0e9cd0..60ccbebec4c8 100644
>> --- a/mm/vmscan.c
>> +++ b/mm/vmscan.c
>> @@ -1412,9 +1412,9 @@ static enum page_references folio_check_references(struct folio *folio,
>>                         return PAGEREF_ACTIVATE;
>>
>>                 /*
>> -                * Activate executable folios after first usage.
>> +                * Activate file-backed executable folios after first usage.
>>                  */
>> -               if (vm_flags & VM_EXEC)
>> +               if ((vm_flags & VM_EXEC) && folio_is_file_lru(folio))
>>                         return PAGEREF_ACTIVATE;
>>
>>                 return PAGEREF_KEEP;
>>
>> Should I send this patch separately or resend the whole series with this new change attached?
>>
> 
> I dropped this patch individually, so there's no need to resend the others.

I see. Thanks!

> .
> 


^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2022-04-28  1:59 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1412,9 +1412,9 @@ static enum page_references folio_check_references(struct folio *folio,

                /*
-                * Activate executable folios after first usage.
+                * Activate file-backed executable folios after first usage.
                 */
2022-04-27  6:25 [nacked] mm-vmscan-activate-swap-backed-executable-folios-after-first-usage.patch removed from -mm tree Andrew Morton
2022-04-27  6:41 ` Miaohe Lin
2022-04-27 14:16   ` Andrew Morton
2022-04-28  1:59     ` Miaohe Lin

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.